======
wizard
======


.. automodule:: camelot.view.wizard
   :members:

.. toctree::

   backup.rst
   importwizard.rst
   merge_document.rst
   new.rst
   new_company.rst
   pages/index.rst
   update_value.rst
